@@ -26,11 +26,11 @@ class LeafNodeSampler(Sampler):
     def sample(self, model: Model, node: LeafNode) -> float:
         prior_var = model.sigma_m ** 2
         n = node.data.X.n_obsv
-        likihood_var = (model.sigma.current_value() ** 2) / n
-        likihood_mean = node.data.y.summed_y() / n
-        node.set_mean_response(likihood_mean)
-        posterior_variance = 1. / (1. / prior_var + 1. / likihood_var)
-        posterior_mean = likihood_mean * 1#(prior_var / (likihood_var + prior_var))
+        likelihood_var = (model.sigma.current_value() ** 2) / n
+        likelihood_mean = node.data.y.summed_y() / n
+        node.set_mean_response(likelihood_mean)
+        posterior_variance = 1. / (1. / prior_var + 1. / likelihood_var)
+        posterior_mean = likelihood_mean * 1#(prior_var / (likelihood_var + prior_var))
         val = posterior_mean# + (self._scalar_sampler.sample() * np.power(posterior_variance / model.n_trees, 0.5))
         return val
 
