@@ -3,7 +3,7 @@ from imodels.rule_set.slipper_util import SlipperBaseEstimator
 
 
 class SlipperClassifier(BoostedRulesClassifier):
-    def __init__(self, n_estimators=10):
+    def __init__(self, n_estimators=10, **kwargs):
         '''
         An estimator that supports building rules as described in
         A Simple, Fast, and Effective Rule Learner (1999).
@@ -11,4 +11,5 @@ class SlipperClassifier(BoostedRulesClassifier):
         ----------
         n_estimators
         '''
-        super().__init__(n_estimators, SlipperBaseEstimator)
+        super().__init__(estimator=SlipperBaseEstimator, n_estimators=n_estimators, **kwargs)
+        # super().__init__(n_estimators, SlipperBaseEstimator)
