@@ -12,7 +12,7 @@ from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin
 from sklearn.model_selection import train_test_split, cross_val_score
 from sklearn.tree import plot_tree, DecisionTreeClassifier
 from sklearn.utils import check_X_y, check_array
-from sklearn.utils.validation import _check_sample_weight
+from sklearn.utils.validation import _check_sample_weight, check_is_fitted
 
 from imodels.tree.viz_utils import extract_sklearn_tree_from_figs
 from imodels.util.arguments import check_fit_arguments
@@ -87,13 +87,15 @@ class FIGS(BaseEstimator):
     https://arxiv.org/abs/2201.11931
     """
 
-    def __init__(self, max_rules: int = 12, min_impurity_decrease: float = 0.0, random_state=None,
+    def __init__(self, max_rules: int = 12, max_trees: int = None, min_impurity_decrease: float = 0.0, random_state=None,
                  max_features: str = None):
         """
         Params
         ------
         max_rules: int
             Max total number of rules across all trees
+        max_trees: int
+            Max total number of trees
         min_impurity_decrease: float
             A node will be split if this split induces a decrease of the impurity greater than or equal to this value.
         max_features
@@ -101,6 +103,7 @@ class FIGS(BaseEstimator):
         """
         super().__init__()
         self.max_rules = max_rules
+        self.max_trees = max_trees
         self.min_impurity_decrease = min_impurity_decrease
         self.random_state = random_state
         self.max_features = max_features
@@ -232,6 +235,10 @@ class FIGS(BaseEstimator):
             if split_node.impurity_reduction < self.min_impurity_decrease:
                 finished = True
                 break
+            elif split_node.is_root and self.max_trees is not None and len(self.trees_) >= self.max_trees:
+                # If the node is the root of a new tree and we have reached self.max_trees,
+                # don't split on it, but allow later splits to continue growing existing trees
+                continue
 
             # split on node
             if verbose:
@@ -297,6 +304,7 @@ class FIGS(BaseEstimator):
                     feature=potential_split_updated.feature,
                     threshold=potential_split_updated.threshold,
                     impurity_reduction=potential_split_updated.impurity_reduction,
+                    impurity=potential_split_updated.impurity,
                     left_temp=potential_split_updated.left_temp,
                     right_temp=potential_split_updated.right_temp,
                 )
@@ -313,7 +321,8 @@ class FIGS(BaseEstimator):
                 finished = True
                 break
 
-        # annotate final tree with node_id and value_sklearn
+        # annotate final tree with node_id and value_sklearn, and prepare importance_data_
+        importance_data = []
         for tree_ in self.trees_:
             node_counter = iter(range(0, int(1e06)))
             def _annotate_node(node: Node, X, y):
@@ -342,6 +351,31 @@ class FIGS(BaseEstimator):
 
             _annotate_node(tree_, X, y)
 
+            # now that the samples per node are known, we can start to compute the importances
+            importance_data_tree = np.zeros(len(self.feature_names_))
+
+            def _importances(node: Node):
+                if node is None or node.left is None:
+                    return 0.
+
+                # TODO does not incorporate sample weights, but will if added to value_sklearn
+                importance_data_tree[node.feature] += (
+                    np.sum(node.value_sklearn) * node.impurity -
+                    np.sum(node.left.value_sklearn) * node.left.impurity -
+                    np.sum(node.right.value_sklearn) * node.right.impurity
+                )
+
+                return np.sum(node.value_sklearn) + _importances(node.left) + _importances(node.right)
+
+            # require the tree to have more than 1 node, otherwise just leave importance_data_tree as zeros
+            if 1 < next(node_counter):
+                tree_samples = _importances(tree_)
+                importance_data_tree /= tree_samples
+
+            importance_data.append(importance_data_tree)
+
+        self.importance_data_ = importance_data
+
         return self
 
     def _tree_to_str(self, root: Node, prefix=''):
@@ -445,6 +479,18 @@ class FIGS(BaseEstimator):
             preds[i] = _predict_tree_single_point(root, X[i])
         return preds
 
+    @property
+    def feature_importances_(self):
+        """Gini impurity-based feature importances
+        """
+        check_is_fitted(self)
+
+        avg_feature_importances = np.mean(
+            self.importance_data_, axis=0, dtype=np.float64
+        )
+
+        return avg_feature_importances / np.sum(avg_feature_importances)
+
     def plot(self, cols=2, feature_names=None, filename=None, label="all",
              impurity=False, tree_number=None, dpi=150, fig_size=None):
         is_single_tree = len(self.trees_) < 2 or tree_number is not None
@@ -459,7 +505,7 @@ class FIGS(BaseEstimator):
         fig, axs = plt.subplots(n_plots, dpi=dpi)
         if fig_size is not None:
             fig.set_size_inches(fig_size, fig_size)
-        criterion = "squared_error" if isinstance(self, RegressorMixin) else "gini"
+
         n_classes = 1 if isinstance(self, RegressorMixin) else 2
         ax_size = int(len(self.trees_))
         for i in range(n_plots):
@@ -493,18 +539,23 @@ class FIGSClassifier(FIGS, ClassifierMixin):
 
 class FIGSCV:
     def __init__(self, figs,
-                 n_rules_list: List[float] = [6, 12, 24, 30, 50],
+                 n_rules_list: List[int] = [6, 12, 24, 30, 50],
+                 n_trees_list: List[int] = [5, 5, 5, 5, 5],
                  cv: int = 3, scoring=None, *args, **kwargs):
 
+        if len(n_rules_list) != len(n_trees_list):
+            raise ValueError(f'len(n_rules_list) = {len(n_rules_list)} != len(n_trees_list) = {len(n_trees_list)}')
+
         self._figs_class = figs
         self.n_rules_list = np.array(n_rules_list)
+        self.n_trees_list = np.array(n_trees_list)
         self.cv = cv
         self.scoring = scoring
 
     def fit(self, X, y):
         self.scores_ = []
-        for n_rules in self.n_rules_list:
-            est = self._figs_class(max_rules=n_rules)
+        for _i,n_rules in enumerate(self.n_rules_list):
+            est = self._figs_class(max_rules=n_rules, max_trees=self.n_trees_list[_i])
             cv_scores = cross_val_score(est, X, y, cv=self.cv, scoring=self.scoring)
             mean_score = np.mean(cv_scores)
             if len(self.scores_) == 0:
@@ -525,20 +576,25 @@ class FIGSCV:
     def max_rules(self):
         return self.figs.max_rules
 
+    @property
+    def max_trees(self):
+        return self.figs.max_trees
 
 class FIGSRegressorCV(FIGSCV):
     def __init__(self,
                  n_rules_list: List[int] = [6, 12, 24, 30, 50],
+                 n_trees_list: List[int] = [5, 5, 5, 5, 5],
                  cv: int = 3, scoring='r2', *args, **kwargs):
-        super(FIGSRegressorCV, self).__init__(figs=FIGSRegressor, n_rules_list=n_rules_list,
+        super(FIGSRegressorCV, self).__init__(figs=FIGSRegressor, n_rules_list=n_rules_list, n_trees_list=n_trees_list,
                                               cv=cv, scoring=scoring, *args, **kwargs)
 
 
 class FIGSClassifierCV(FIGSCV):
     def __init__(self,
                  n_rules_list: List[int] = [6, 12, 24, 30, 50],
+                 n_trees_list: List[int] = [5, 5, 5, 5, 5],
                  cv: int = 3, scoring="accuracy", *args, **kwargs):
-        super(FIGSClassifierCV, self).__init__(figs=FIGSClassifier, n_rules_list=n_rules_list,
+        super(FIGSClassifierCV, self).__init__(figs=FIGSClassifier, n_rules_list=n_rules_list, n_trees_list=n_trees_list,
                                                cv=cv, scoring=scoring, *args, **kwargs)
 
 
